@@ -1,17 +1,17 @@
 ;(function(){
   var map = {
-  "commitId": "c36192f84629a03bf436e19198e10c0deb263443",
-  "branchName": "release-client-5.13.x",
-  "buildTime": "Mon, 27 Feb 2023 01:50:51 GMT",
-  "buildVersion": "5.1.296",
+  "commitId": "9987e42baec8a630e36c99b340aab6e9e020e35b",
+  "branchName": "release",
+  "buildTime": "Fri, 17 Mar 2023 16:35:53 GMT",
+  "buildVersion": "5.1.318",
   "css": [
-    "@zoom/client-calendar/static/css/default~app.175ea1dd.css",
+    "@zoom/client-calendar/static/css/default~app.391672d7.css",
     "@zoom/client-calendar/static/css/vendors~app.f43a7829.css"
   ],
   "js": [
-    "@zoom/client-calendar/static/js/default~app.52058614.js",
-    "@zoom/client-calendar/static/js/vendors~app.700ab55d.js",
-    "@zoom/client-calendar/static/js/app.7b88a06c.js"
+    "@zoom/client-calendar/static/js/default~app.c93cb147.js",
+    "@zoom/client-calendar/static/js/vendors~app.1f3ccfa0.js",
+    "@zoom/client-calendar/static/js/app.e0fcfa75.js"
   ]
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
